#!/bin/csh

# Runs needed in proofs for AB-game with white-peg answers

make clean

##########
# 2 pegs #
##########

echo
echo "The values from Table 1"
echo "ab(2,c) for c = 2, 3, ..., 13"
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  foreach t ("2 2" "3 3" "4 3" "5 4" "6 4" "7 5" "8 5" "9 6" "10 6" "11 7" "12 7" "13 8")
    set tt=(${t})
    set c=${tt[1]}
    set q1=${tt[2]}
    @ q2 = ${q1} - 1
    make p=2 c=${c} q=${q1}
    ./mm
    if ($? != 1) then
      echo ERROR
      exit
    endif
    make p=2 c=${c} q=${q2}
    ./mm
    if ($? != 0) then
      echo ERROR
      exit
    endif
  end
endif

echo
echo "The lower bound for 2 pegs and at least 3 colors"
echo "ab_*(2,3) = 3"
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  make p=2 c=3 a=1 q=3
  ./mm
  if ($? != 1) then
    echo ERROR
    exit
  endif
  make p=2 c=3 a=1 q=2
  ./mm
  if ($? != 0) then
    echo ERROR
    exit
  endif
endif

echo
echo "The upper bound for 2 pegs and at least 5 colors"
echo "ab(2,5,2) = ab(2,6,2) = 4"
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  foreach t ("5" "6")
    make p=2 c=${t} x=2 q=4
    ./mm
    if ($? != 1) then
      echo ERROR
      exit
    endif
    make p=2 c=${t} x=2 q=3
    ./mm
    if ($? != 0) then
      echo ERROR
      exit
    endif
  end
endif

##########
# 3 pegs #
##########

echo
echo "The values from Table 1"
echo "ab(3,c) for c = 3, 4, ..., 13"
echo "Warning, the computation of ab(3,13) <= 7 takes about 3 hours."
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  foreach t ("3 4" "4 4" "5 4" "6 5" "7 5" "8 6" "9 6" "10 6" "11 7" "12 7" "13 7")
    set tt=(${t})
    set c=${tt[1]}
    set q1=${tt[2]}
    @ q2 = ${q1} - 1
    make p=3 c=${c} q=${q1}
    ./mm
    if ($? != 1) then
      echo ERROR
      exit
    endif
    make p=3 c=${c} q=${q2}
    ./mm
    if ($? != 0) then
      echo ERROR
      exit
    endif
  end
endif

echo
echo "The lower bound for 3 pegs and at least 8 colors"
echo "ab_*(3,8) = 6"
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  make p=3 c=8 a=2 q=6
  ./mm
  if ($? != 1) then
    echo ERROR
    exit
  endif
  make p=3 c=8 a=2 q=5
  ./mm
  if ($? != 0) then
    echo ERROR
    exit
  endif
endif

echo
echo "The upper bound for 3 pegs and at least 14 colors"
echo "ab(3,14,3) = ab(3,15,3) = ab(3,16,3) = 8"
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  foreach t ("14" "15" "16")
    make p=3 c=${t} x=3 q=8
    ./mm
    if ($? != 1) then
      echo ERROR
      exit
    endif
    make p=3 c=${t} x=3 q=7
    ./mm
    if ($? != 0) then
      echo ERROR
      exit
    endif
  end
endif

##########
# 4 pegs #
##########

echo
echo "The values from Table 1"
echo "ab(4,c) for c = 4, 5, ..., 11"
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  foreach t ("4 5" "5 5" "6 5" "7 6" "8 6" "9 6" "10 7" "11 7")
    set tt=(${t})
    set c=${tt[1]}
    set q1=${tt[2]}
    @ q2 = ${q1} - 1
    make p=4 c=${c} q=${q1}
    ./mm
    if ($? != 1) then
      echo ERROR
      exit
    endif
    make p=4 c=${c} q=${q2}
    ./mm
    if ($? != 0) then
      echo ERROR
      exit
    endif
  end
endif

echo
echo "The values from Table 1"
echo "ab(4,c) for c = 12, 13"
echo "Warning, these computations take about 120 and 16 days, respectively."
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  foreach t ("12 8" "13 8")
    set tt=(${t})
    set c=${tt[1]}
    set q1=${tt[2]}
    @ q2 = ${q1} - 1
    make p=4 c=${c} q=${q1}
    ./mm
    if ($? != 1) then
      echo ERROR
      exit
    endif
    make p=4 c=${c} q=${q2}
    ./mm
    if ($? != 0) then
      echo ERROR
      exit
    endif
  end
endif

echo
echo "The upper bound for 4 pegs"
echo "ab(4,c) <= 9 for c = 14, 15, 16"
echo "Warning, the computation takes about 1 hour."
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  foreach t ("14 9" "15 9" "16 9")
    set tt=(${t})
    make p=4 c=${tt[1]} q=${tt[2]}
    ./mm
    if ($? != 1) then
      echo ERROR
      exit
    endif
  end
endif

echo
echo "The upper bound for 4 pegs and at least 17 colors"
echo "ab(4,c,4) <= 10 for c = 17, 18, 19, 20"
echo "Warning, the computation takes about 2.5 hours."
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  foreach t ("17 10" "18 10" "19 10" "20 10")
    set tt=(${t})
    make p=4 c=${tt[1]} x=4 q=${tt[2]}
    ./mm
    if ($? != 1) then
      echo ERROR
      exit
    endif
  end
endif

echo
echo "The lower bound for 4 pegs and at least 10 colors"
echo "ab_*(4,10) > 6"
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  make p=4 c=10 a=3 q=6
  ./mm
  if ($? != 0) then
    echo ERROR
    exit
  endif
endif

echo
echo "The lower bound for 4 pegs and at least 13 colors"
echo "ab_*(4,13) > 7"
echo "Warning, this computation takes about 80 days."
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  make p=4 c=13 a=3 q=7
  ./mm
  if ($? != 0) then
    echo ERROR
    exit
  endif
endif

###################################
# Equal number of pegs and colors #
###################################

echo
echo "Equal number of pegs and colors"
echo "ab(p,p) for p = 2, 3, 4, 5, 6"
echo "Do you want to run this test? (y/n)"
set CONFIRM = $<
if (${CONFIRM} == "y") then
  foreach t ("2 2" "3 4" "4 5" "5 6" "6 7")
    set tt=(${t})
    set p=${tt[1]}
    set q1=${tt[2]}
    @ q2 = ${q1} - 1
    make p=${p} c=${p} q=${q1}
    ./mm
    if ($? != 1) then
      echo ERROR
      exit
    endif
    make p=${p} c=${p} q=${q2}
    ./mm
    if ($? != 0) then
      echo ERROR
      exit
    endif
  end
endif

make clean
