#ifndef _ANSWER_H_
#define _ANSWER_H_  1

#include <algorithm>

#if FUNCTION < 10 // AB-game

// The number of possible answers
static const int possible_answers = (PEGS * (PEGS + 3) / 2);

static char const * const game_name = "ab";

class Answer {
  public:
    Answer() {}

    // Answer is coded as an integer, e.g.
    //           |     #marks
    //           |  0  1  2  3  4
    // ----------+---------------
    // #blacks 0 |  0  1  3  6 10
    //         1 |     2  4  7 11
    //         2 |        5  8 12
    //         3 |           9
    //         4 |             13
    // #marks = #blacks + #whites
    Answer(int code) {
      if (code == possible_answers - 1)
        marks = blacks = pegs;
      else {
        marks = 0;
        while (code > marks) {
          ++marks;
          code -= marks;
        }
        blacks = code;
      }
    }

    Answer(Configuration const &conf, Configuration const &question) {
      // Static tables are faster. There must be a place for an
      // additional color, but only in question. This place can be
      // assigned but it is never read, hence it do not need to be
      // initialized.
      static int color_conf[colors], color_question[colors + 1];
      for (int i = 0; i < colors; ++i)
        color_conf[i] = color_question[i] = 0;

      blacks = 0;
      for (int i = 0; i < pegs; ++i) {
        if (conf[i] == question[i]) {
          ++blacks;
        }
        // Formal definiton...
        // ++color_conf[(int)conf[i]];
        // ++color_question[(int)question[i]];
        // ... but each color appears at most one time.
        // We do not care about an additional color.
        color_conf[(int)conf[i]] = 1;
        color_question[(int)question[i]] = 1;
      }

      marks = 0;
      for (int i = 0; i < colors; ++i) {
        // Formal definition...
        // marks += ::std::min(color_conf[i], color_question[i]);
        // ... but each color appears at most one time.
        // An additional color is not counted.
        marks += color_conf[i] & color_question[i];
      }
    }

    // Answer is coded as an integer, e.g.
    //           |     #whites
    //           |  0  1  2  3  4
    // ----------+---------------
    // #blacks 0 |  0  1  3  6 10
    //         1 |  2  4  7 11
    //         2 |  5  8 12
    //         3 |  9
    //         4 | 13
    // #marks = #blacks + #whites
    int Code() const {
      // int m = ((marks * (marks + 1)) >> 1) + blacks;
      int m = ((marks * marks + marks) >> 1) + blacks;
      if (m == possible_answers)
        --m;
      return m;
    }

    int B() const {
      return blacks;
    }

    int W() const {
      return marks - blacks;
    }

  private:
    int marks;  // The number of blacks + whites
    int blacks; // The number of blacks
};

#else /* FUNCTION >= 10, AB-game without white-peg answers */

// The number of possible answers
static const int possible_answers = (PEGS + 1);

static char const * const game_name = "abb";

class Answer {
  public:
    Answer() {}

    Answer(int code) {
      blacks = code;
    }

    Answer(Configuration const &conf, Configuration const &question) {
      blacks = 0;
      for (int i = 0; i < pegs; ++i) {
        if (conf[i] == question[i])
          ++blacks;
      }
    }

    int Code() const {
      return blacks;
    }

    int B() const {
      return blacks;
    }

    int W() const {
      return 0;
    }

  private:
    int blacks; // The number of blacks
};

#endif /* BLACK_PEG_ONLY */

#endif
